@@ -3,39 +3,39 @@ import os
 from os import path
 import shutil
 import viset.download
-import cv2
-import cv2.cv as cv
+import pylab
 import numpy as np 
 import urllib
 import socket
 import hashlib
+import time
 
 socket.setdefaulttimeout(10)  # for urlretrieve
 
-class About(tables.IsDescription):
+class AboutTable(tables.IsDescription):
   version = tables.Int64Col(pos=0)   
   name = tables.StringCol(256, pos=1)   
   task = tables.StringCol(256, pos=1)     
   image = tables.StringCol(256, pos=1)  # hint for binary decode
 
-class Package(tables.IsDescription):
+class PackageTable(tables.IsDescription):
   url = tables.StringCol(512, pos=1)   
   sha1 = tables.StringCol(512, pos=1)     
   path = tables.StringCol(512, pos=1)   
 
-class Image(tables.IsDescription):
+class ImageTable(tables.IsDescription):
   id = tables.Int64Col(pos=0)   
   url = tables.StringCol(512, pos=1)   
   id_anno = tables.Int64Col(pos=2)   
   n_anno = tables.Int32Col(pos=3)   
   
-class CategorizationAnnotation(tables.IsDescription):
+class CategorizationAnnotationTable(tables.IsDescription):
   id = tables.Int64Col(pos=0)
   id_img = tables.Int64Col(pos=1)
   id_category = tables.Int32Col(pos=2)  
   category = tables.StringCol(256, pos=3)      
 
-class DetectionAnnotation(tables.IsDescription):
+class DetectionAnnotationTable(tables.IsDescription):
   id = tables.Int64Col(pos=0)   
   id_img = tables.Int64Col(pos=0)
   category = tables.Int32Col()   
@@ -90,11 +90,11 @@ class Viset(object):
     id = self.db.root.dataset.annotation.cols.id_category[:]
     return 2*(np.int32(id == id_category)) - 1
   
-  def image(self, im, verbose=False):
+  def image(self, im):
     id = im['id']
     if self.imtype == 'Package':
       # Local path
-      im = cv2.imread(self.db.root.dataset.images[id]['url'])
+      im = pylab.imread(self.db.root.dataset.images[id]['url'])
     elif self.imtype == 'url':
       url = self.db.root.dataset.images[id]['url']
       filename = path.join(self.cachedir,hashlib.sha1(url).hexdigest()+os.path.splitext(url)[1])
@@ -102,13 +102,14 @@ class Viset(object):
         print 'Retrieving ' + url
         try:
           urllib.urlretrieve(url, filename)
-          im = cv2.imread(filename)                
+          im = pylab.imread(filename)
         except:
           print 'Download failed ... skipping\n'
-          cv.WaitKey(1000)  # 1ms
+          time.sleep(1)  # for ctrl-c
           im = None
       else:
-        im = cv2.imread(filename)      
+        im = pylab.imread(filename)
+
     elif self.imtype == 'MNIST':
       # binary reader for MNIST
       im = None
@@ -118,8 +119,6 @@ class Viset(object):
     else:
       raise IOError("undefined image type"+str(self.imtype))
 
-    if verbose is True and im is not None:
-      cv.ShowImage('Image', cv.fromarray(im))
     return im
   
     # this returns an numpy structured array
@@ -136,7 +135,7 @@ class Viset(object):
     for id in range(id_start,id_end,n_skip):
       anno = self.db.root.dataset.annotation[id]
       if (category is None) or (anno['category'] in category):
-        im = self.image(self.db.root.dataset.images[id], verbose=False)
+        im = self.image(self.db.root.dataset.images[id])
         anno = self.db.root.dataset.annotation[id]
         yield (im,anno)  # tuple
       
@@ -144,13 +143,13 @@ class Viset(object):
     # HDF5 file structure
     db = tables.open_file(dbfile, mode = "w", title = dbname)
     group = db.create_group("/", 'dataset', 'Dataset')
-    tbl_about = db.create_table(group, 'about', About, expectedrows=1, title='About')    
-    tbl_packages = db.create_table(group, 'packages', Package, title='Packages', expectedrows=10)
-    tbl_images = db.create_table(group, 'images', Image, title='Images', filters=tables.Filters(complevel=1), expectedrows=1000000)
+    tbl_about = db.create_table(group, 'about', AboutTable, expectedrows=1, title='About')    
+    tbl_packages = db.create_table(group, 'packages', PackageTable, title='Packages', expectedrows=10)
+    tbl_images = db.create_table(group, 'images', ImageTable, title='Images', filters=tables.Filters(complevel=1), expectedrows=1000000)
     if task == 'Categorization':
-      tbl_anno = db.create_table(group, 'annotation', CategorizationAnnotation, title='Annotation', filters=tables.Filters(complevel=1), expectedrows=1000000)
+      tbl_anno = db.create_table(group, 'annotation', CategorizationAnnotationTable, title='Annotation', filters=tables.Filters(complevel=1), expectedrows=1000000)
     elif task == 'Detection':
-      tbl_anno = db.create_table(group, 'annotation', DetectionAnnotation, title='Annotation', filters=tables.Filters(complevel=1), expectedrows=1000000)
+      tbl_anno = db.create_table(group, 'annotation', DetectionAnnotationTable, title='Annotation', filters=tables.Filters(complevel=1), expectedrows=1000000)
     else:
       pass
 
